@@ -375,7 +375,7 @@ sub timestamp {
     file_timestamp( $_[0]->file );
 }
 
-# generate a sum file is desired
+# generate a sum file if desired
 # but extend to copy when long-term storage is not working storage
 sub accepted_for_out {
     my $self = shift;
@@ -416,11 +416,6 @@ use MooseX::Role::Parameterized;
 use MooseX::Types::Path::Class qw(Dir File);
 use Moose::Util::TypeConstraints;
 
-sub generator {
-	my ($class,@args) = @_;
-	return sub { $class->new( file => @_, @args ) };
-}
-
 subtype 'HPCIFileGen',
     as 'CodeRef';
 
@@ -428,6 +423,10 @@ coerce 'HPCIFileGen',
     from 'Str',      via { _create_HPCIFileGen(  $_ ) },
     from 'ArrayRef', via { _create_HPCIFileGen( @$_ ) };
 
+sub _create_HPCIFileGen {
+	return sub { shift->new( @_ ) };
+}
+
 sub _create_HPCIFileGenHash {
     my $key = shift;
     return { $key => _create_HPCIFileGen( @_ ) };
