@@ -155,7 +155,10 @@ role {
 			. qq{", with return value:     $status}
 		);
 
-		$run->_collect_job_stats( $status );
+		my $status_handler = $run->stage->_has_command
+			? '_collect_job_stats'
+			: '_base_register_status';
+		$run->$status_handler( $status );
 
 		return $run;
 	};
@@ -171,6 +174,7 @@ role {
 			my ( $run_command, $soft_timeout, $hard_timeout ) = $run->_get_submit_command;
 			$self->info("  wrapped submit command: $run_command");
 			$self->info("     actual user command: $command");
+			$stage->_build_script_file;
 			my $pid = $run->_submit_command( $run_command );
 			$self->info("                     pid: $pid");
 			$self->_runs->{$pid} = $run;
@@ -186,7 +190,7 @@ role {
 			return $run;
 		}
 		else { # _has_code
-			my $stat = $stage->code->();
+			my $stat = $stage->code->() || 0;
 			$self->_reap_run( $run, $stat );
 		}
 	};
